@@ -1,4 +1,5 @@
 import numpy as np
+from aperturedb.Query import QueryBuilder
 
 import logging
 logger = logging.getLogger(__name__)
@@ -14,18 +15,12 @@ class TestEntityLoader():
         if not condition:
             raise AssertionError("Condition not true")
 
-    def remove_entities(self, utils, classes):
-        for c in classes:
-            # Assert that we have a clean slate to begin with.
-            self.assertEqual(utils.remove_entities(c), True)
-            self.assertEqual(utils.count_entities(c), 0)
-
     def test_Loader(self, utils, insert_data_from_csv):
         classes = ["_Image", "_Descriptor", "Person", "_BoundingBox"]
-        self.remove_entities(utils, classes)
+        self.assertTrue(utils.remove_all_objects())
 
         results = [utils.create_entity_index(
-            e, "id", "integer") for e in classes]
+            e, "id") for e in classes]
         self.assertTrue(all(results))
 
         # Insert Person Nodes
@@ -47,8 +42,7 @@ class TestEntityLoader():
         self.assertEqual(len(data), utils.count_bboxes())
 
     def test_LoaderDescriptorsImages(self, utils, insert_data_from_csv):
-        classes = ["_Image", "_Descriptor", "_DescriptorSet"]
-        self.remove_entities(utils, classes)
+        self.assertTrue(utils.remove_all_objects())
 
         # Insert Images, images may be there already, and that case should
         # be handled correctly by contraints
@@ -75,8 +69,7 @@ class TestEntityLoader():
 
     def test_BlobLoader(self, db, utils, insert_data_from_csv):
         # Assert that we have a clean slate to begin with.
-        self.assertEqual(utils.remove_entities("_Blob"), True)
-        self.assertEqual(utils.count_entities("_Blob"), 0)
+        self.assertTrue(utils.remove_all_objects())
 
         data = insert_data_from_csv(in_csv_file = "./input/blobs.adb.csv")
         self.assertEqual(len(data), utils.count_entities("_Blob"))
@@ -99,9 +92,7 @@ class TestEntityLoader():
 
     def test_conditional_add(self, utils, insert_data_from_csv):
         logger.debug(f"Cleaning existing data")
-
-        self.assertTrue(utils.remove_entities("_BoundingBox"))
-        self.assertTrue(utils.remove_entities("_Image"))
+        self.assertTrue(utils.remove_all_objects())
         # insert one of the images from image csv, for bboxes to refer to.
         images = insert_data_from_csv(
             in_csv_file="./input/images.adb.csv", rec_count=1)
@@ -123,17 +114,17 @@ class TestURILoader():
                 "Expected {}, got {}".format(expected, actual))
 
     def test_S3Loader(self, utils, insert_data_from_csv):
-        self.assertEqual(utils.remove_entities("_Image"), True)
+        self.assertEqual(utils.remove_all_objects(), True)
         data = insert_data_from_csv(in_csv_file = "./input/s3_images.adb.csv")
         self.assertEqual(len(data), utils.count_images())
 
     def test_HttpImageLoader(self, utils, insert_data_from_csv):
-        self.assertEqual(utils.remove_entities("_Image"), True)
+        self.assertEqual(utils.remove_all_objects(), True)
         data = insert_data_from_csv(
             in_csv_file = "./input/http_images.adb.csv")
         self.assertEqual(len(data), utils.count_images())
 
     def test_GSImageLoader(self, utils, insert_data_from_csv):
-        self.assertEqual(utils.remove_entities("_Image"), True)
+        self.assertEqual(utils.remove_all_objects(), True)
         data = insert_data_from_csv(in_csv_file = "./input/gs_images.adb.csv")
         self.assertEqual(len(data), utils.count_images())
